@@ -1,6 +1,7 @@
 #' @title Slack based measure of superefficiency model
 #'   
-#' @description Slack based measure of superefficiency model (Tone 2002) with n DMUs, m inputs, s outputs...
+#' @description Slack based measure of superefficiency model (Tone 2002) with \code{n}
+#' DMUs, \code{m} inputs and \code{s} outputs.
 #' 
 #' @usage model_sbmsupereff(datadea,
 #'                   dmu_eval = NULL,
@@ -22,22 +23,29 @@
 #' If \code{NULL} (default), all DMUs are considered.
 #' @param dmu_ref A numeric vector containing which DMUs are the evaluation reference set.
 #' If \code{NULL} (default), all DMUs are considered.
-#' @param weight_input A value, vector of length \code{m}, or matrix \code{m} x \code{ne} (where \code{ne} is the length of \code{dmu_eval})
-#'                     with weights to inputs corresponding to the relative importance of items.
-#' @param weight_output A value, vector of length \code{m}, or matrix \code{m} x \code{ne} (where \code{ne} is the length of \code{dmu_eval})
-#'                      with weights to outputs corresponding to the relative importance of items.
-#' @param orientation A string, equal to "no" (non-oriented), "io" (input-oriented) or "oo" (output-oriented).
+#' @param weight_input A value, vector of length \code{m}, or matrix \code{m} x
+#' \code{ne} (where \code{ne} is the length of \code{dmu_eval}) with weights to
+#' inputs corresponding to the relative importance of items.
+#' @param weight_output A value, vector of length \code{m}, or matrix \code{m} x
+#' \code{ne} (where \code{ne} is the length of \code{dmu_eval}) with weights to
+#' outputs corresponding to the relative importance of items.
+#' @param orientation A string, equal to "no" (non-oriented), "io" (input-oriented)
+#' or "oo" (output-oriented).
 #' @param rts A string, determining the type of returns to scale, equal to "crs" (constant),
-#'            "vrs" (variable), "nirs" (non-increasing), "ndrs" (non-decreasing) or "grs" (generalized).
+#' "vrs" (variable), "nirs" (non-increasing), "ndrs" (non-decreasing) or "grs" (generalized).
 #' @param L Lower bound for the generalized returns to scale (grs).
 #' @param U Upper bound for the generalized returns to scale (grs).
-#' @param compute_target Logical. If it is \code{TRUE}, it computes targets, superslacks (\code{t_input} and \code{t_output}) and slacks.
-#' @param compute_rho Logical. If it is \code{TRUE}, it computes the SBM efficiency score (applying \code{model_sbmeff})
-#' of the DMU (\code{project_input}, \code{project_output}).
-#' @param kaizen Logical. If \code{TRUE}, the kaizen version of SBM (Tone 2010), also known as SBM-Max, is computed for the efficiency score
-#' of the DMU (\code{project_input}, \code{project_output}).
-#' @param silent Logical. If \code{FALSE} (default) it prints all the messages from function \code{maximal_friends}.
-#' @param returnlp Logical. If it is \code{TRUE}, it returns the linear problems (objective function and constraints).
+#' @param compute_target Logical. If it is \code{TRUE}, it computes targets,
+#' superslacks (\code{t_input} and \code{t_output}) and slacks.
+#' @param compute_rho Logical. If it is \code{TRUE}, it computes the SBM efficiency
+#' score (applying \code{model_sbmeff}) of the DMU (\code{project_input}, \code{project_output}).
+#' @param kaizen Logical. If \code{TRUE}, the kaizen version of SBM (Tone 2010),
+#' also known as SBM-Max, is computed for the efficiency score of the DMU
+#' (\code{project_input}, \code{project_output}).
+#' @param silent Logical. If \code{FALSE} (default) it prints all the messages
+#' from function \code{maximal_friends}.
+#' @param returnlp Logical. If it is \code{TRUE}, it returns the linear problems
+#' (objective function and constraints).
 #'   
 #' @author 
 #' \strong{Vicente Coll-Serrano} (\email{vicente.coll@@uv.es}).
@@ -53,11 +61,17 @@
 #'  
 #' @references 
 #' 
-#' Tone, K. (2002). "A slacks-based measure of super-efficiency in data envelopment analysis", European Journal of Operational Research, 143, 32-41. \doi{10.1016/S0377-2217(01)00324-1}  
+#' Tone, K. (2002). "A slacks-based measure of super-efficiency in data envelopment
+#' analysis", European Journal of Operational Research, 143, 32-41.
+#' \doi{10.1016/S0377-2217(01)00324-1}  
 #'
-#' Tone, K. (2010). "Variations on the theme of slacks-based measure of efficiency in DEA", European Journal of Operational Research, 200, 901-907. \doi{10.1016/j.ejor.2009.01.027}
+#' Tone, K. (2010). "Variations on the theme of slacks-based measure of efficiency
+#' in DEA", European Journal of Operational Research, 200, 901-907.
+#' \doi{10.1016/j.ejor.2009.01.027}
 #'   
-#' Cooper, W.W.; Seiford, L.M.; Tone, K. (2007). Data Envelopment Analysis. A Comprehensive Text with Models, Applications, References and DEA-Solver Software. 2nd Edition. Springer, New York. \doi{10.1007/978-0-387-45283-8}
+#' Cooper, W.W.; Seiford, L.M.; Tone, K. (2007). Data Envelopment Analysis.
+#' A Comprehensive Text with Models, Applications, References and DEA-Solver Software.
+#' 2nd Edition. Springer, New York. \doi{10.1007/978-0-387-45283-8}
 #' 
 #' @examples 
 #' # Replication of results in Tone(2002, p.39)
@@ -72,7 +86,8 @@
 #' slacks(result)$slack_input
 #' references(result)
 #' 
-#' @seealso \code{\link{model_sbmeff}}, \code{\link{model_supereff}}, \code{\link{model_addsupereff}}
+#' @seealso \code{\link{model_sbmeff}}, \code{\link{model_supereff}},
+#' \code{\link{model_addsupereff}}
 #' 
 #' @import lpSolve
 #' 
@@ -99,16 +114,6 @@ model_sbmsupereff <-
     stop("Data should be of class deadata. Run read_data function first!")
   }
     
-  # Checking non-controllable or non-discretionary inputs/outputs
-  #if ((!is.null(datadea$nc_inputs)) || (!is.null(datadea$nc_outputs))
-  #    || (!is.null(datadea$nd_inputs)) || (!is.null(datadea$nd_outputs))) {
-  #  warning("This model does not take into account non-controllable or non-discretionary feature for inputs/outputs.")
-  #  datadea$nc_inputs <- NULL
-  #  datadea$nc_outputs <- NULL
-  #  datadea$nd_inputs <- NULL
-  #  datadea$nd_outputs <- NULL
-  #}
-    
   # Checking undesirable io and rts
   if (!is.null(datadea$ud_inputs) || !is.null(datadea$ud_outputs)) {
     warning("This model does not take into account the undesirable feature for inputs/outputs.")
@@ -266,11 +271,11 @@ model_sbmsupereff <-
     }
   }
   
-  # Matriz técnica
+  # Constraints matrix
   f.con.1 <- cbind(0, inputref, -diag(ni), matrix(0, nrow = ni, ncol = no))
   f.con.2 <- cbind(0, outputref, matrix(0, nrow = no, ncol = ni), -diag(no))
   
-  # Vector de dirección de restricciones y matriz técnica
+  # Directions vector and constraints matrix
   if (orientation == "no") {
     f.dir <- c("=", dir1, dir2, dir3, dir4)
   } else if (orientation == "io") {
@@ -283,14 +288,13 @@ model_sbmsupereff <-
   f.dir[1 + c(nc_inputs, ni + nc_outputs, ni + no + nc_inputs, ni + no + ni + nc_outputs)] <- "="
   f.dir <- c(f.dir, "=", f.dir.rs)
   
-  # Vector de términos independientes
+  # Right hand side vector
   f.rhs <- c(1, rep(0, ni + no + ni + no + 1), f.rhs.rs)
   
   for (i in 1:nde) {
     
     ii <- dmu_eval[i]
     
-    # Vector de coeficientes de la función objetivo, Matriz técnica y Vector de dirección de restricciones
     if (orientation == "no") {
       f.obj <- c(0, rep(0, ndr), weight_input[, i] / (sumwi[i] * input[, ii]), rep(0, no))
       f.con.0 <- c(0, rep(0, ndr), rep(0, ni), weight_output[, i] / (sumwo[i] * output[, ii]))
@@ -300,7 +304,7 @@ model_sbmsupereff <-
       f.obj <- c(0, rep(0, ndr), rep(0, ni), weight_output[, i] / (sumwo[i] * output[, ii]))
     }
       
-    # Matriz técnica
+    # Constraints matrix
     f.con.3 <- cbind(-input[, ii], matrix(0, nrow = ni, ncol = ndr), diag(ni), matrix(0, nrow = ni, ncol = no))
     f.con.4 <- cbind(-output[, ii], matrix(0, nrow = no, ncol = (ndr + ni)), diag(no))
     f.con.se <- rep(0, ndr)
@@ -318,9 +322,10 @@ model_sbmsupereff <-
       names(tproject_input) <- inputnames
       tproject_output <- rep(0, no)
       names(tproject_output) <- outputnames
-      var <- list(t = t, tlambda = tlambda, tproject_input = tproject_input, tproject_output = tproject_output)
-      DMU[[i]] <- list(direction = obj, objective.in = f.obj, const.mat = f.con, const.dir = f.dir, const.rhs = f.rhs,
-                       var = var)
+      var <- list(t = t, tlambda = tlambda, tproject_input = tproject_input,
+                  tproject_output = tproject_output)
+      DMU[[i]] <- list(direction = obj, objective.in = f.obj, const.mat = f.con,
+                       const.dir = f.dir, const.rhs = f.rhs, var = var)
       
     } else {
       
